@@ -3,10 +3,9 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.2012';
+our $VERSION = '0.2100';
 
-use Algorithm::Combinatorics qw(variations_with_repetition);
-use MIDI::Util qw(dura_size set_time_signature);
+use MIDI::Util qw(set_time_signature);
 use Music::Duration;
 
 use Moo;
@@ -401,56 +400,6 @@ sub write {
     $self->score->write_score( $self->file );
 }
 
-
-sub steady {
-    my ( $self, $instrument, $opts ) = @_;
-
-    $instrument ||= $self->closed_hh;
-
-    $opts->{duration} ||= $self->quarter;
-
-    for my $n ( 1 .. $self->counter ) {
-        $self->note( $opts->{duration}, $instrument );
-    }
-}
-
-
-sub combinatorial {
-    my ( $self, $instrument, $opts ) = @_;
-
-    $instrument ||= $self->snare;
-
-    $opts->{negate}   ||= 0;
-    $opts->{count}    ||= 0;
-    $opts->{beats}    ||= $self->beats;
-    $opts->{repeat}   ||= 4;
-    $opts->{duration} ||= $self->quarter;
-    $opts->{vary}     ||= {
-        0 => sub { $self->rest( $opts->{duration} ) },
-        1 => sub { $self->note( $opts->{duration}, $instrument ) },
-    };
-
-    my $size = dura_size( $opts->{duration} );
-
-    my @items = $opts->{patterns}
-        ? @{ $opts->{patterns} }
-        : sort map { join '', @$_ }
-            variations_with_repetition( [ keys %{ $opts->{vary} } ], $opts->{beats} );
-
-    for my $pattern (@items) {
-        next if $pattern =~ /^0+$/;
-
-        $pattern =~ tr/01/10/ if $opts->{negate};
-
-        for ( 1 .. $opts->{repeat} ) {
-            for my $bit ( split //, $pattern ) {
-                $opts->{vary}{$bit}->();
-                $self->counter( $self->counter + $size ) if $opts->{count};
-            }
-        }
-    }
-}
-
 1;
 
 __END__
@@ -465,7 +414,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.2012
+version 0.2100
 
 =head1 SYNOPSIS
 
@@ -833,61 +782,12 @@ references.
 Output the score as a MIDI file with the module L</file> attribute as
 the file name.
 
-=head2 steady
-
-  $d->steady;
-  $d->steady( $d->kick );
-  $d->steady( $d->kick, { duration => $d->eighth } );
-
-Play a steady beat with the given B<instrument> and optional
-B<duration>, for the number of beats accumulated in the object's
-B<counter> attribute.
-
-Defaults:
-
-  instrument: closed_hh
-  Option:
-    duration: quarter
-
-=head2 combinatorial
-
-  $d->combinatorial;
-  $d->combinatorial( $d->kick );
-  $d->combinatorial( $d->kick, \%options );
-
-Play a beat pattern with the given B<instrument>, given by
-L<Algorithm::Combinatorics/variations_with_repetition>.
-
-This method accumulates beats in the object's B<counter> attribute if
-the B<count> option is set.
-
-The B<vary> option is a hashref of coderefs, keyed by single character
-tokens, like the digits, 0-9.  The coderef durations should add up to
-the B<duration> option.
-
-Defaults:
-
-  instrument: snare
-  Options:
-    duration: quarter
-    count: 0
-    negate: 0
-    beats: beats
-    repeat: 4
-    duration: quarter
-    vary:
-        0 => sub { $self->rest( $options->{duration} ) },
-        1 => sub { $self->note( $options->{duration}, $instrument ) },
-    patterns: undef
-
 =head1 SEE ALSO
 
 The F<eg/*> programs in this distribution. Also
 F<eg/drum-fills-advanced> in the L<Music::Duration::Partition>
 distribution.
 
-L<Algorithm::Combinatorics>
-
 L<Math::Bezier>
 
 L<MIDI::Util>
@@ -900,9 +800,6 @@ L<https://en.wikipedia.org/wiki/General_MIDI#Percussion>
 
 L<https://en.wikipedia.org/wiki/General_MIDI_Level_2#Drum_sounds>
 
-L<https://www.amazon.com/dp/0882847953> -
-"Progressive Steps to Syncopation for the Modern Drummer"
-
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
